@@ -38,7 +38,7 @@ class GetConfigOperationPrivate : public ConfigOperationPrivate
 public:
     GetConfigOperationPrivate(GetConfigOperation::Options options, GetConfigOperation *qq);
 
-    void backendReady(org::kde::kscreen::Backend* backend) Q_DECL_OVERRIDE;
+    void backendReady(org::kde::kscreen::Backend* backend) override;
     void onConfigReceived(QDBusPendingCallWatcher *watcher);
     void onEDIDReceived(QDBusPendingCallWatcher *watcher);
 
@@ -182,7 +182,6 @@ void GetConfigOperation::start()
 void GetConfigOperationPrivate::loadEdid(KScreen::AbstractBackend* backend)
 {
     Q_ASSERT(BackendManager::instance()->method() == BackendManager::InProcess);
-    Q_Q(GetConfigOperation);
     if (options & KScreen::ConfigOperation::NoEDID) {
         return;
     }
